"""
This module contains the global configurations of the framework
"""

#: This name suppose to be used for general meta decoration for functions,
#: methods or even classes
meta_field = '_pyrsmeta'
